"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processConflicts = void 0;
const core_1 = require("@salesforce/core");
const writeConflictTable = (conflicts, ux) => {
    ux.table(conflicts.map((conflict) => ({ ...conflict, state: 'Conflict' })), {
        columns: [
            { label: 'STATE', key: 'state' },
            { label: 'FULL NAME', key: 'name' },
            { label: 'TYPE', key: 'type' },
            { label: 'PROJECT PATH', key: 'filenames' },
        ],
    });
};
/**
 * Write a table (if not json) and throw an error that includes a custom message and the conflict data
 *
 * @param conflicts
 * @param ux
 * @param message
 */
const processConflicts = (conflicts, ux, message) => {
    if (conflicts.length === 0) {
        return;
    }
    writeConflictTable(conflicts, ux);
    const err = new core_1.SfdxError(message);
    err.setData(conflicts);
    throw err;
};
exports.processConflicts = processConflicts;
//# sourceMappingURL=conflicts.js.map