"use strict";
/*
 * Copyright (c) 2021, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenResultFormatter = void 0;
const core_1 = require("@salesforce/core");
const resultFormatter_1 = require("./resultFormatter");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/plugin-source', 'open');
class OpenResultFormatter extends resultFormatter_1.ResultFormatter {
    constructor(logger, ux, result) {
        super(logger, ux);
        this.result = result;
    }
    getJson() {
        return this.result;
    }
    display() {
        if (this.isSuccess()) {
            this.ux.warn(messages.getMessage('SecurityWarning'));
            this.ux.log();
            const { orgId, username, url } = this.result;
            this.ux.log(messages.getMessage('SourceOpenCommandHumanSuccess', [orgId, username, url]));
        }
        else {
            throw new core_1.SfdxError(messages.getMessage('SourceOpenCommandError'), 'OpenFailed');
        }
    }
}
exports.OpenResultFormatter = OpenResultFormatter;
//# sourceMappingURL=openResultFormatter.js.map