import { UX } from '@salesforce/command';
import { Logger } from '@salesforce/core';
import { RetrieveResult, MetadataApiRetrieveStatus, FileResponse, RequestStatus, RetrieveMessage } from '@salesforce/source-deploy-retrieve';
import { ResultFormatter, ResultFormatterOptions } from './resultFormatter';
export interface PackageRetrieval {
    name: string;
    path: string;
}
export interface RetrieveResultFormatterOptions extends ResultFormatterOptions {
    packages?: PackageRetrieval[];
}
export interface RetrieveCommandResult {
    inboundFiles: FileResponse[];
    packages: PackageRetrieval[];
    warnings: RetrieveMessage[];
    response: MetadataApiRetrieveStatus;
}
export declare class RetrieveResultFormatter extends ResultFormatter {
    protected packages: PackageRetrieval[];
    protected result: RetrieveResult;
    protected fileResponses: FileResponse[];
    protected warnings: RetrieveMessage[];
    constructor(logger: Logger, ux: UX, options: RetrieveResultFormatterOptions, result: RetrieveResult);
    /**
     * Get the JSON output from the RetrieveResult.
     *
     * @returns RetrieveCommandResult
     */
    getJson(): RetrieveCommandResult;
    /**
     * Displays retrieve results in human format.
     */
    display(): void;
    protected hasStatus(status: RequestStatus): boolean;
    protected hasComponents(): boolean;
    private displayWarnings;
    private displaySuccesses;
    private displayErrors;
}
